(import ikernel.*)
(import nrc.fuzzy.*)
(import java.lang.*)
    (deftemplate Tag  		(declare (from-class Tag)))
    
    ;; Two globals to hold our two FuzzyVariables for temperature and pressure
    (defglobal ?*tempFvar* = (new nrc.fuzzy.FuzzyVariable "temperature" 0.0 100.0 "C"))
    (defglobal ?*pressFvar* = (new nrc.fuzzy.FuzzyVariable "pressure" 0.0 10.0 "kilo-pascals"))

    (defrule gettagdata
        (Tag{label == "g1.temp.ar.frio.gerador1" && value == ?value})
      =>
        (assert (g1.temp.ar.frio.gerador1 ?value))
        ;(printout t "Variavel " ?value crlf)
    )
    
    ;; An initialization rule that adds the terms to the FuzzyVariables and
    ;; asserts the input FuzzyValue 'temperature is very medium'
    (defrule init
       (g1.temp.ar.frio.gerador1 ?value)
      =>
       (load-package nrc.fuzzy.jess.FuzzyFunctions)
       (bind ?xHot  (create$ 25.0 100.0))
       (bind ?yHot  (create$ 0.0 1.0))
       (bind ?xCold (create$ 0.0 15.0))
       (bind ?yCold (create$ 1.0 0.0))
       ;; terms for the temperature Fuzzy Variable
       (?*tempFvar* addTerm "hot" ?xHot ?yHot 2)
       (?*tempFvar* addTerm "cold" ?xCold ?yCold 2)
       (?*tempFvar* addTerm "veryHot" "very hot")
       (?*tempFvar* addTerm "medium" "not hot and (not cold)")
       ;; terms for the pressure Fuzzy Variable
       (?*pressFvar* addTerm "low" (new ZFuzzySet 2.0 5.0))
       (?*pressFvar* addTerm "medium" (new PIFuzzySet 5.0 2.5))
       (?*pressFvar* addTerm "high" (new SFuzzySet 2.0 5.0))

       ;; add the fuzzy input -- temperature is very medium
       ;(assert (theTemp (new FuzzyValue ?*tempFvar* "very medium")))
       ;(printout t "crispvalue1: " ?value crlf)
       (assert (theTemp (new FuzzyValue ?*tempFvar* (new SingletonFuzzySet (build ?value)) )))
       ;(printout t "crispvalue2: " ?value crlf)    
    )

    ;; the rule 'if temperature hot then pressure low or medium'
    (defrule temp-hot-press-low
       (theTemp ?t&:(fuzzy-match ?t "hot"))
     =>
       (assert (thePress (new FuzzyValue ?*pressFvar* "low")))
    )
    
    (defrule temp-low-press-high
       (theTemp ?t&:(fuzzy-match ?t "cold"))
     =>
       (assert (thePress (new FuzzyValue ?*pressFvar* "high")))
    )

    (defrule temp-medium-press-medium
       (theTemp ?t&:(fuzzy-match ?t "medium"))
     =>
       (assert (thePress (new FuzzyValue ?*pressFvar* "medium")))
    )
    
    (defrule defuzzyfication
        (thePress ?p)
        (Tag{label == "g1.temp.ar.frio.gerador2"} (OBJECT ?tt))
      =>
        (bind ?outvalue (?p centerOfAreaDefuzzify))
        ;(printout t "Defuzzyficacao: " ?outvalue crlf)
        ;(printout t "teste: " (call ?tt getValue) crlf)
        (call ?tt setValue (call (new Double (build ?outvalue)) toString))
    )
    ; a rule to print some interesting things
    ;(defrule do-the-printing
    ;   (theTemp ?t)
    ;   (thePress ?p)
    ; =>
    ;   (printout t "Temp is: " (?t toString) crlf "Press is: " (?p toString) crlf)
    ;   (bind ?theFzVals
    ;        (create$ (new nrc.fuzzy.FuzzyValue ?*tempFvar* "hot") ?t)
    ;   )
    ;   (printout t (call nrc.fuzzy.FuzzyValue plotFuzzyValues "*+" ?theFzVals) crlf)
    ;   (printout t (call (new nrc.fuzzy.FuzzyValue ?*pressFvar* "low or medium")
    ;                      plotFuzzyValue "*") crlf)
    ;   (printout t (?p plotFuzzyValue "*") crlf)
    ;)